# Man set

> set - set subject, scenario, model, defaultCommand parameter. When the command is called without parameters it will print the current settings.

## Usage

`set`

`set subject testing_001`

`set model text-davinci-003`

`set scenario Zork`